===================
System Requirements
===================

This is the System Requirements Specification.


System capabilities
===================


Saying hello
------------
.. item:: SYS_0001 Saying hello

   The system will say hello.

Saying goodbye
--------------
.. item:: SYS_0002 Saying goodbye
   :depends_on: SYS_0001

   The systems will say goodbye

.. item:: SYS_0003 Say nothing

   The systems will say nothing

Reference to item :item:`r001`
